@@ -49,6 +49,7 @@ class Reservation(JSONField):
         self.pending_state = None
         self.reservation_state = None
         self.notices = None
+        self.lease_end = None
 
     def get_name(self) -> str:
         return self.name
@@ -124,7 +125,7 @@ class Reservation(JSONField):
                 d[k] = d[k].to_json()
         if len(d) == 0:
             return ''
-        return json.dumps(d, skipkeys=True, sort_keys=True)
+        return json.dumps(d, skipkeys=True, sort_keys=True, indent=4)
 
 
 class ReservationFactory:
